@@ -50,8 +50,27 @@ for standard in standards:
     if standard == "3166-2":
         sort_key = "code"
     iso[standard].sort(key=lambda item: item[sort_key])
+
     # Write the sorted JSON file
     with open("data/iso_" + standard + ".json", "w", encoding="utf-8") as json_file:
         json.dump(iso, json_file, ensure_ascii=False, indent=2, sort_keys=True)
         # Add a final newline
         json_file.write("\n")
+
+    # Check for codes that are assigned more than once
+    keys = ["alpha_2", "alpha_3", "alpha_4", "numeric", "code"]
+    for key in keys:
+        # Skip ISO 3166-3 with data that has been withdrawn,
+        # here are multiple keys expected
+        if standard == "3166-3":
+            continue
+        values = []
+        for item in iso[standard]:
+            if key in item:
+                if item[key] not in values:
+                    values.append(item[key])
+                else:
+                    print(
+                        "Error in ISO %s: key '%s' has multiple entries for value '%s'."
+                        % (standard, key, item[key])
+                    )
